import greenfoot.*;
/**
 * an actor that has a periodic color intensity 
 */
public class Drop extends Actor
{
    static int[][] parts = { {0,0,1}, {0,1,0}, {1,0,0}, {0,1,1}, {1,0,1}, {1,1,0}, {1,1,1} }; // used color parts per color
    static int color = 6; // the color number
    static int frequency = 3; // the speed factor
    static int radius = 0; // the maximum distance out an actor can be from the center of the wave
    
    int tint; // the color intensity value
    int hyp; // twenty times the distance this actor is from center of the wave

    /**
     * saves the radial distance and creates the proper sized image for this actor
     */
    public Drop()
    {
        GreenfootImage image = new GreenfootImage(5, 5);
        image.fill();
    }
    
    /**
     * actor removed if outside radial distance; otherwise the initial tint value is determined
     *
     * @param world the world in which this object was placed
     */
    public void addedToWorld(World world)
    {
        hyp = (int)(Math.hypot(24-getX(), 24-getY())*20); // twenty times distance from center of wave
        if (radius != 0 && hyp/20 > radius) world.removeObject(this); // remove this Drop object if outside the radial limit
        tint = 510-(hyp%511); // set initial tint value
    }

    /**
     * produce wave effect by adjusting tint (color intensity)
     */
    public void act()
    {
        tint = (tint+frequency)%511; // add a small change to the tint value 
        int c = (int)Math.abs(tint-255); // determine new color parts value
        getImage().setColor(new Color(c*parts[color][0], c*parts[color][1], c*parts[color][2])); // set the new drawing color
        if (radius > 0 && hyp > 0) getImage().setTransparency(255-(int)((((double)(hyp/20))/(double)radius)*255.0)); // add fading
        getImage().fill(); // fills the image with the new color
    }
    
    /**
     * class method to change the main color of the wave
     *
     * @param val a number between zero and six that determines which color parts to use
     */
    public static void setColor(int val)
    {
        color = val;
    }
    
    /**
     * class method to change the maximum radial distance a Drop object can be from the center of the wave
     *
     * @param val the maximum radial distance from the center of the wave
     */
    public static void setRadius(int val)
    {
        radius = val;
    }
}