import greenfoot.*;

/**
 * a class used to represent creation of wave pulses using the world background and a radial limit
 * 
 * Author: danpost
 * Version: 1.0.0
 */
public class Medium2 extends World
{
    final static int[][] parts = { {0,0,1}, {0,1,0}, {1,0,0}, {0,1,1}, {1,0,1}, {1,1,0}, {1,1,1} };
    static int color = 6;
    
    int freq = 3, radius = 24;
    int[][] tint = new int[48][48];
    
    /**
     * assigns the array elements their initial tint values and adds a Num object to the new world (to show world number)
     */
    public Medium2()
    {    
        super(48, 48, 5);
        getBackground().setColor(Color.BLACK);
        getBackground().fill();
        for (int i=0; i<48; i++) for (int j=0; j<48; j++)
        {
            int hyp = (int)Math.hypot(24-i, 24-j); // distance from center of wave
            if(hyp <= radius) tint[i][j]=510-(int)((Math.hypot(24-i, 24-j)*20))%511; else tint[i][j] = -1;
        }
        addObject(new Num(5), 2, 2);
    }
    
    /**
     * checks mouse clicks (for changing worlds) and keystrokes (for changing speed) and produces wave effect
     */
    public void act()
    {
        // checks for mouse click
        if(Greenfoot.mouseClicked(null)) Greenfoot.setWorld(new Medium());
        // checks for keystrokes
        String key = Greenfoot.getKey();
        if ("up".equals(key) && freq < 24) freq++;
        if ("down".equals(key) && freq > 1) freq--;
        if (key != null && "1234567".indexOf(key)>-1) color = "1234567".indexOf(key);
        // produce wave effect by constantly changing tint values
        for (int i=0; i<48; i++) for (int j=0; j<48; j++) // for each area
        {
            if (tint[i][j] != -1)
            {
                tint[i][j] = (tint[i][j]+freq)%511; // make a change to tint value
                int hyp = (int)Math.hypot(24-i, 24-j); // distance from center of wave
                int c = (int)Math.abs(tint[i][j]-255); // get value of color parts
                c = (int)((double)c*Math.sqrt(1.0-(double)hyp/(double)radius));
                getBackground().setColor(new Color(c*parts[color][0], c*parts[color][1], c*parts[color][2])); // sets the new drawing color
                getBackground().fillRect(i*5, j*5, 5, 5); // fills the specified area
            }
        }
    }
}